=== renamed file 'src/raw-tools.plugin' => 'src/raw-tools.eog-plugin'
--- src/raw-tools.plugin	2011-11-01 00:26:24 +0000
+++ src/raw-tools.eog-plugin	2011-04-08 15:43:38 +0000
@@ -1,7 +1,7 @@
-[Plugin]
-Loader=python
+[Eog Plugin]
 Module=raw-tools
 IAge=2
+Loader=python
 Name=Raw Tools
 Icon=postr
 Description=Tools to deal withraw images saved along-side the viewed images

=== modified file 'src/raw-tools.py'
--- src/raw-tools.py	2011-11-01 00:26:24 +0000
+++ src/raw-tools.py	2011-09-22 21:51:14 +0000
@@ -22,42 +22,39 @@
 
 # version 0.1
 
-from gi.repository import GObject, Gtk, Eog
-import os, re, gio
-
-class RawToolsPlugin( GObject.Object, Eog.WindowActivatable ):
-
-    # Override EogWindowActivatable's window property
-    window = GObject.property( type = Eog.Window )
-
-    # list of file extension to recognise as RAW files
+
+import eog, gtk, os, re, gio
+
+class RawToolsPlugin(eog.Plugin):
+
     raw_file_extensions = [ 'cr2', '3fr', 'ari', 'arw', 'srf', 'sr2', 'bay',
         'crw', 'cr2', 'cap', 'iiq', 'eip', 'dcs', 'dcr', 'drf', 'k25', 'kdc',
         'dng', 'erf', 'fff', 'mef', 'mos', 'mrw', 'nef', 'nrw', 'orf', 'ptx',
         'pef', 'pxn', 'r3d', 'raf', 'raw', 'rw2', 'rwl', 'rwz', 'x3f' ]
 
     def __init__( self ):
-        GObject.Object.__init__( self )
+        eog.Plugin.__init__( self )
 
-    def do_activate( self ):
+    def activate( self, window ):
+        self._window = window
 
         # insert menu item
-        ui_manager = self.window.get_ui_manager()
-        self.action_group = Gtk.ActionGroup( 'EogRawToolsPluginActions' )
-        self.action_group.add_actions( [ ( 'EogPluginRunKeepRaw', None,
+        manager = window.get_ui_manager()
+        self._action_group = gtk.ActionGroup( 'EogRawToolsPluginActions' )
+        self._action_group.add_actions( [ ( 'EogPluginRunKeepRaw', None,
             _( 'Keep Raw Image' ), 'K',
             _( "Move the accompanying raw file to a 'raw' subdirectory" ),
-            self.do_keep_raw_image ) ], self.window )
-        self.action_group.add_actions( [ ( 'EogPluginRunUnkeepRaw', None,
+            self.on_keep_raw_image ) ] )
+        self._action_group.add_actions( [ ( 'EogPluginRunUnkeepRaw', None,
             _( 'Unkeep Raw Image' ), 'U',
             _( "Move the accompanying raw file back to the image's directory" ),
-            self.do_unkeep_raw_image ) ], self.window )
-        self.action_group.add_actions( [ ( 'EogPluginRunDeleteRaw', None,
+            self.on_unkeep_raw_image ) ] )
+        self._action_group.add_actions( [ ( 'EogPluginRunDeleteRaw', None,
             _( 'Delete Unkept Raw Images' ), None,
             _( "Delete all raw files in the current image's directory (the unkept ones)" ),
-            self.do_delete_raw_images ) ], self.window )
-        ui_manager.insert_action_group( self.action_group, -1 )
-        self.ui_id = ui_manager.add_ui_from_string( """
+            self.on_delete_raw_images ) ] )
+        manager.insert_action_group( self._action_group, -1 )
+        self._ui_id = manager.add_ui_from_string( """
             <ui>
                 <menubar name="MainMenu">
                     <menu name="ToolsMenu" action="Tools">
@@ -80,37 +77,36 @@
         """ )
 
         # insert status bar
-        self.statusbar = Gtk.Statusbar()
-        #self.statusbar.set_size_request( 100, 10 )
-        statusbar = self.window.get_statusbar()
-        statusbar.pack_end( self.statusbar, False, False, 0 );
-        self.statusbar.show()
+        self._statusbar = gtk.Statusbar()
+        self._statusbar.set_has_resize_grip( False )
+        self._statusbar.set_size_request( 80, 10 )
+        statusbar = window.get_statusbar()
+        statusbar.pack_end( self._statusbar, False, False, 0 );
+        self._statusbar.show()
 
         # connect to selection change
-        thumb_view = self.window.get_thumb_view()
-        self.on_selection_change_id = thumb_view.connect_after( \
-            'selection_changed', self.on_selection_change, self.window )
+        thumb_view = window.get_thumb_view()
+        self._on_selection_change_id = thumb_view.connect_after( \
+            'selection_changed', self.on_selection_change, window )
 
         # init ui state
-        self.update_status( self.window )
-
-    def do_deactivate( self ):
+        self.update_status( window )
+
+    def deactivate( self, window ):
+
+        # disconnect handlers
+        thumb_view = window.get_thumb_view()
+        thumb_view.disconnect( self._on_selection_change_id )
 
         # remove menu items
-        ui_manager = self.window.get_ui_manager()
-        ui_manager.remove_ui( self.ui_id )
-        self.ui_id = 0
-        ui_manager.remove_action_group( self.action_group )
-        self.action_group = None
-        ui_manager.ensure_update()
-
-        # disconnect handlers
-        thumb_view = self.window.get_thumb_view()
-        thumb_view.disconnect( self.on_selection_change_id )
+        manager = window.get_ui_manager()
+        manager.remove_ui( self._ui_id )
+        manager.remove_action_group( self._action_group )
+        manager.ensure_update()
 
         # remove status bar entry
-        statusbar =  self.window.get_statusbar()
-        Gtk.Container.remove( statusbar, self.statusbar )
+        statusbar = window.get_statusbar()
+        statusbar.remove( self._statusbar )
 
     def on_selection_change( self, view, data ):
         self.update_status( data )
@@ -164,7 +160,7 @@
 
         # do we have just the one selected image? we can't handle multiple
         # images because EogThumbView.get_selected_images() doesn't work.
-        self.action_group.set_sensitive( \
+        self._action_group.set_sensitive( \
             thumb_view.get_n_selected() == 1 )
 
         # update the status bar
@@ -172,19 +168,19 @@
             image = thumb_view.get_first_selected_image()
             raw_fname = self.get_raw_filename_from_image( image )
             path = os.path.dirname( image.get_file().get_path() )
-            self.statusbar.pop( 0 )
+            self._statusbar.pop( 0 )
             if( raw_fname is False ):
-                self.statusbar.push( 0, "  " + _( 'raw: -' ) )
+                self._statusbar.push( 0, _( 'raw: -' ) )
             elif( os.path.isfile( path + '/' + raw_fname ) ):
-                self.statusbar.push( 0, "  " + _( 'raw: unkept' ) )
+                self._statusbar.push( 0, _( 'raw: unkept' ) )
             else:
-                self.statusbar.push( 0, "  " + _( 'raw: keep' ) )
+                self._statusbar.push( 0, _( 'raw: keep' ) )
 
-    def do_keep_raw_image( self, action, window ):
+    def on_keep_raw_image( self, action ):
 
         # do we have just the one selected image? we can't handle multiple
         # images because EogThumbView.get_selected_images() doesn't work.
-        thumb_view = window.get_thumb_view()
+        thumb_view = self._window.get_thumb_view()
         if( thumb_view.get_n_selected() == 1 ):
 
             # get the image
@@ -193,13 +189,13 @@
                 self.keep_raw_image( image )
 
             # update ui
-            self.update_status( window )
+            self.update_status( self._window )
 
-    def do_unkeep_raw_image( self, action, window ):
+    def on_unkeep_raw_image( self, action ):
 
         # do we have just the one selected image? we can't handle multiple
         # images because EogThumbView.get_selected_images() doesn't work.
-        thumb_view = window.get_thumb_view()
+        thumb_view = self._window.get_thumb_view()
         if( thumb_view.get_n_selected() == 1 ):
 
             # get the image
@@ -208,14 +204,14 @@
                 self.unkeep_raw_image( image )
 
             # update ui
-            self.update_status( window )
+            self.update_status( self._window )
 
     def keep_raw_image( self, image ):
 
         raw_fname = self.get_raw_filename_from_image( image )
         if( raw_fname is False ):
-            dialog = Gtk.MessageDialog( None, Gtk.DialogFlags.MODAL,
-                Gtk.MessageType.INFO, Gtk.ButtonsType.CLOSE,
+            dialog = gtk.MessageDialog( None, gtk.DIALOG_MODAL,
+                gtk.MESSAGE_INFO, gtk.BUTTONS_CLOSE,
                 _( 'Raw file not found!' ) )
             dialog.format_secondary_text( _( "This image doesn't appear to " +
                 "have an accompanying raw file." ) )
@@ -238,8 +234,8 @@
 
         raw_fname = self.get_raw_filename_from_image( image )
         if( raw_fname is False ):
-            dialog = Gtk.MessageDialog( None, Gtk.DialogFlags.MODAL,
-                Gtk.MessageType.INFO, Gtk.ButtonsType.CLOSE,
+            dialog = gtk.MessageDialog( None, gtk.DIALOG_MODAL,
+                gtk.MESSAGE_INFO, gtk.BUTTONS_CLOSE,
                 _( 'Raw file not found!' ) )
             dialog.format_secondary_text( _( "This image doesn't appear to " +
                 "have an accompanying raw file." ) )
@@ -258,10 +254,10 @@
             if( len( os.listdir( path + '/raw' ) ) == 0 ):
                 os.rmdir( path + '/raw' )
 
-    def do_delete_raw_images( self, action, window ):
+    def on_delete_raw_images( self, action ):
 
         # get path to first selected image, if there is one
-        thumb_view = window.get_thumb_view()
+        thumb_view = self._window.get_thumb_view()
         if( thumb_view.get_n_selected() == 1 ):
             image = thumb_view.get_first_selected_image()
             path = os.path.dirname( image.get_file().get_path() )
@@ -280,8 +276,8 @@
             if( len( files ) > 0 ):
 
                 # ask the user if they are sure
-                dialog = Gtk.MessageDialog( None, Gtk.DialogFlags.MODAL,
-                    Gtk.MessageType.QUESTION, Gtk.ButtonsType.YES_NO,
+                dialog = gtk.MessageDialog( None, gtk.DIALOG_MODAL,
+                    gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO,
                     _( 'Delete Raw Files?' ) )
                 if( len( files ) == 1 ):
                     subject = _( ' remaining raw file' )
@@ -295,7 +291,7 @@
                         "Do you want to continue?" ) )
                 result = dialog.run()
                 dialog.destroy()
-                if( result != Gtk.ResponseType.YES ):
+                if( result != gtk.RESPONSE_YES ):
                     return
 
                 # delete the files
@@ -303,12 +299,12 @@
                     gio.file_parse_name( path + '/' + file ).trash()
                     #os.unlink( path + '/' + file )
 
-                self.update_status( window )
+                self.update_status( self._window )
         
             # else, tell the user there aren't any raw files!
             else:
-                dialog = Gtk.MessageDialog( None, Gtk.DialogFlags.MODAL,
-                    Gtk.MessageType.INFO, Gtk.ButtonsType.CLOSE,
+                dialog = gtk.MessageDialog( None, gtk.DIALOG_MODAL,
+                    gtk.MESSAGE_INFO, gtk.BUTTONS_CLOSE,
                     _( 'No raw files to delete!' ) )
                 dialog.format_secondary_text(
                     _( 'There are no raw files to delete!' ) )

